// -*-C++-*-
//
// File:      ExposureButton.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Mon Jul  9 11:25:19 MET DST 2001

#include "ExposureButton.h"
#include "ExposurePalette.h"
#include <qtooltip.h>
using namespace OdfBrowser;

ExposureButton::ExposureButton(OdfInfo::ObservationExposure* exposure,
			       QWidget* parent, const char* name) 
  : QPushButton(parent,name), _exposure(exposure)
{
  // set the color scheme for this exposure
  setPalette(ExposurePalette::instance()->palette(_exposure->mode()));
  setToggleButton (true);
  setText(_exposure->id().c_str());

  // initial state
  _state=ID;

  // Create a tooltip with global information.
  QString tip=QString("Id: ")+QString(_exposure->id().c_str());
  tip+=QString("\nMode: ") + Xmm::toString(_exposure->mode()).c_str();
  tip+=QString("\nFilter: ") + Xmm::toString(_exposure->filter()).c_str();
  tip+=QString("\nStart: ") + _exposure->start().toString().c_str();
  tip+=QString("\nEnd: ") + _exposure->stop().toString().c_str();
  QToolTip::add(this,tip);

  if (OdfBrowser::toModeType(_exposure->mode()) == OdfBrowser::Engineering) 
    QPushButton::hide();

  connect(this,SIGNAL(toggled(bool)),this,SLOT(useId(bool)));
}

ExposureButton::~ExposureButton()
{
}

void ExposureButton::toggleText()
{
  // toggle state first!
  switch(_state) {
  case ID:
    _state=MODE;break;
  case MODE:
    _state=FILTER;break;
  case FILTER:
    _state=ID;break;
  };

  // select text
  switch(_state) {
  case ID:
    setText(_exposure->id().c_str());break;
  case MODE:
    setText(Xmm::toString(_exposure->mode()).c_str());break;
  case FILTER:
    setText(Xmm::toString(_exposure->filter()).c_str());break;
  };


}

void ExposureButton::useId(bool on)
{
  emit selected(_exposure,on);
}

void ExposureButton::show(OdfBrowser::ModeType m,bool filter)
{
  if (OdfBrowser::toModeType(_exposure->mode()) == m) {
    if (filter) QPushButton::show(); else QPushButton::hide();
  }
}
