// -*-C++-*-
//
// File:      ExposureButtonsView.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Mon Jul  9 11:25:07 MET DST 2001

#include "ExposureButtonsView.h"
#include "ExposureButton.h"
#include "ExposureTimeBar.h"
#include <map>
#include <iostream>
using namespace OdfBrowser;

ExposureButtonsView::ExposureButtonsView(const OdfInfo::Odf* odf,
					 QWidget* parent, const char* name) :
  QScrollView(parent,name),
  _odf(odf), _dx(0),_dy(10),_by(20),_mx(1000),_my(400)
{
  enableClipper(true);

  // create a white background in the viewport
  QPalette pal=palette();
  QColorGroup cg=pal.active();
  cg.setColor( QColorGroup::Background, Qt::white );
  pal.setActive(cg);
  cg=pal.normal();
  cg.setColor( QColorGroup::Background, Qt::white );
  pal.setInactive(cg);
  viewport()->setPalette(pal);

  // adding rows of exposures for each instrument
  int y=_dy;
  addView(Xmm::EMOS1,y);
  y+=_dy+_by;

  addView(Xmm::EMOS2,y);
  y+=_dy+_by;

  addView(Xmm::RGS1,y);
  y+=_dy+_by;

  addView(Xmm::RGS2,y);
  y+=_dy+_by;

  addView(Xmm::EPN,y);
  y+=_dy+_by;

  addView(Xmm::OM,y);
  y+=_dy+_by;

  // adding time axis
  addChild(new ExposureTimeBar(_odf->start(),_odf->stop(),_mx,viewport()),0,y);

  // create initial size, and scrollbars
  _my=y + _dy + /*size of ExposureTimeBar*/ 2 * _by;
  resizeContents (_mx,_my);
  setMinimumWidth(_mx/3);
  setMinimumHeight(_my);
  setVScrollBarMode(AlwaysOff);

}

ExposureButtonsView::~ExposureButtonsView()
{
}


void ExposureButtonsView::addView(Xmm::Instrument i,int y)
{
  errstr << "addView::"
	 << Xmm::toString(i)
	 << Sas::message(Msg::AppLib,Msg::Verbose);

  // scan the exposures for current instrument, and add them to the viewport
  double duration=_odf->stop() - _odf->start();
  const OdfInfo::ObservationExposureList& l=_odf->observationExposures(i);
  for (OdfInfo::ObservationExposureList::const_iterator it=l.begin();
       it != l.end();it++) {
    
    OdfInfo::ObservationExposure* e=(*it);

    errstr << "   "   <<  e->start().toString().c_str()
	   << " <-> " <<  e->stop().toString().c_str()
	   << ", "    <<  e->id().c_str()
	   << Sas::message(Msg::AppLib,Msg::Verbose);


    ExposureButton* b=new ExposureButton(e,viewport());

    // the size of the button is determined by the exposure length
    b->setFixedSize((e->stop()-e->start())/duration*_mx,_by);
    addChild(b,(e->start() - _odf->start())/duration*_mx,y);

    // 
    connect(this,SIGNAL(toggleText()),b,SLOT(toggleText()));

    // selection forwarding from button to this
    connect(b, SIGNAL(selected(OdfInfo::ObservationExposure*,bool)),
	    this,SIGNAL(selected(OdfInfo::ObservationExposure*,bool)));

    // filter forwarding
    connect(this, SIGNAL(filtered(OdfBrowser::ModeType,bool)),
	    b,    SLOT(show(OdfBrowser::ModeType,bool)));
    
  }
}


