// -*-C++-*-
//
// File:      ExposuresView.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Thu Jul 12 15:24:00 MET DST 2001

#include "ExposuresView.h"
#include "ExposureButtonsView.h"
#include <qlabel.h>
#include <qlayout.h>

namespace OdfBrowser {
  class InstrLabel : public QLabel
  {
  public:
    InstrLabel(const QString& txt,QWidget* parent) : QLabel(txt,parent)
      {
	/* // color scheme
	   QPalette pal;
	   QColorGroup cg;
	   cg.setColor( QColorGroup::Background, white );
	   cg.setColor( QColorGroup::Foreground, black );
	   pal.setActive( cg );
	   pal.setInactive( cg );
	   pal.setDisabled( cg );
	   setPalette(pal);
	*/

	// font
	QFont f=font();
	f.setWeight (QFont::Bold);
	setFont(f);

	// frame
	//setAlignment(AlignRight);
	//setMargin(0);
	setFrameStyle( WinPanel | Raised );
	// setFixedHeight(.8*height());
      }
  };
};

using namespace OdfBrowser;

ExposuresView::ExposuresView(const OdfInfo::Odf* odf,
			     QWidget* parent, const char* name) : 
  QWidget(parent,name)
{
  /* layout!

    +------+---------------------------+
    | EMOS1| XXX XXXXXXXXXXXXXXXXXXXXX |
    | EMOS2|   XXXXXXXXXXXXXXXXXXX     |
    | RGS1 |XXXXXXXXXXXXXXXX           |
    | RGS2 |        XXXXXXXXXXXXXXXXXX |
    | EPN  |XXXXXXXXXXXXXXXXXXXXXXXXXXX|
    | OM   |XXX X XXXX XXX XXXXXX XX X |
    |      |<=========================>|
    +------+---------------------------+
   */



  QBoxLayout* hl = new QHBoxLayout(this);   // contains labels and scrollview

  // instrument labels
  QWidget* labels = new QWidget(this,"Labels");
  hl->addWidget(labels); // ..and add it to top row

  int x=0,y=10,dx=10,bx=80,dy=10,by=20;
  QLabel* instr=0;
  instr = new InstrLabel("EMOS1",labels);
  instr->setGeometry( QRect( x, y, bx, by ) );
  y+=dy+by;

  instr = new InstrLabel("EMOS2",labels);
  instr->setGeometry( QRect( x, y, bx, by ) );
  y+=dy+by;

  instr = new InstrLabel("RGS1",labels);
  instr->setGeometry( QRect( x, y, bx, by ) );
  y+=dy+by;

  instr = new InstrLabel("RGS2",labels);
  instr->setGeometry( QRect( x, y, bx, by ) );
  y+=dy+by;

  instr = new InstrLabel("EPN",labels);
  instr->setGeometry( QRect( x, y, bx, by ) );
  y+=dy+by;

  instr = new InstrLabel("OM",labels);
  instr->setGeometry( QRect( x, y, bx, by ) );
  y+=dy+by;

  // time label
  QLabel* timeLabel=new QLabel(" time [ks]",labels);
  timeLabel->setGeometry( QRect( x, y, bx, by ) );
  y+=dy+by;

  // make sure the labels are still readable!
  labels->setMinimumWidth(bx);
  hl->addSpacing(dx);

  

  // exposures
  ExposureButtonsView* bv=new ExposureButtonsView(odf,this,"ExposureButtons");
  hl->addWidget(bv);  // ..and add it to top row

  // forward clicked buttons in the button view to externals
  connect(bv,   SIGNAL(selected(OdfInfo::ObservationExposure*,bool)),
	  this, SIGNAL(selected(OdfInfo::ObservationExposure*,bool)));

  // forward incoming signals to the button view
  connect(this, SIGNAL(toggleText()),
	  bv,   SIGNAL(toggleText()));
  connect(this, SIGNAL(filtered(OdfBrowser::ModeType,bool)),
	  bv,   SIGNAL(filtered(OdfBrowser::ModeType,bool)));

}

ExposuresView::~ExposuresView()
{
}
