// -*-C++-*-
//
// File:      OdfBrowserGui.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Mon Jul  2 17:23:18 MET DST 2001

#include "OdfBrowserGui.h"
#include "OdfInfoView.h"
#include "ExposuresView.h"
#include "ProcButton.h"
#include "RunButton.h"
#include "FilterButton.h"
#include <qtoolbar.h>
#include <qtoolbutton.h>
#include "toggle_text.xpm"
#include <qmenubar.h>
#include <qlayout.h>
#include <qapplication.h>

using namespace OdfBrowser;

OdfBrowserGui::OdfBrowserGui(const char* name) : SasTaskWindow(name)
{
  // menu:
  QPopupMenu* file=new QPopupMenu(this,"FileMenu");
  file->insertItem("E&xit",1);
  connect(file,SIGNAL(activated(int)),qApp,SLOT(quit()));
  menuBar()->insertItem("&File", file,-1,0);
  
  const OdfInfo::Odf* odf=OdfInfo::server->odf();

  // Central Widget creation
  QWidget* centralWidget=new QWidget(this,"Central Widget");
  setCentralWidget(centralWidget);

  QBoxLayout* vl = new QVBoxLayout(centralWidget,10,5);
  OdfInfoView* infoView = new OdfInfoView(odf,
					  centralWidget,
					  "Odf Information");
  ExposuresView* exposuresView = new ExposuresView(odf,
					 centralWidget,
					 "Exposures View");
  vl->addWidget(infoView);
  vl->addWidget(exposuresView);

  

  // Toolbar
  QToolBar* bar  = new QToolBar( this, "button operations" );

  // Toolbar-toggle button
  {
    QPixmap pm(toggle_text);
    new QToolButton(pm, "Toggle information", QString::null,
		    exposuresView, SIGNAL(toggleText()), bar, "ButtonTextToggler" );
  }

  // Toolbar-filter button
  {
    FilterButton* fb=new FilterButton(bar,"ButtonFilter");
    connect(fb,SIGNAL(filtered(OdfBrowser::ModeType,bool)),
	    exposuresView,SIGNAL(filtered(OdfBrowser::ModeType,bool)));
  }
  bar->addSeparator();

  // Run button:
  RunButton* launch=new RunButton(bar);
  bar->addSeparator();
  


  // Toolbar-proc buttons
  ProcButton* proc;
  proc=ProcButton::instantiate(Xmm::EMOS1,bar); // also true for EMOS2
  connect(exposuresView,SIGNAL(selected(OdfInfo::ObservationExposure*,bool)),
	  proc,SLOT(selected(OdfInfo::ObservationExposure*,bool)));
  connect(proc,SIGNAL(selected(Info::Task*,bool)),
	  launch,SLOT(select(Info::Task*,bool)));

  proc=ProcButton::instantiate(Xmm::RGS1,bar); // also true for RGS2
  connect(exposuresView,SIGNAL(selected(OdfInfo::ObservationExposure*,bool)),
	  proc,SLOT(selected(OdfInfo::ObservationExposure*,bool)));
  connect(proc,SIGNAL(selected(Info::Task*,bool)),
	  launch,SLOT(select(Info::Task*,bool)));

  proc=ProcButton::instantiate(Xmm::EPN,bar); //
  connect(exposuresView,SIGNAL(selected(OdfInfo::ObservationExposure*,bool)),
	  proc,SLOT(selected(OdfInfo::ObservationExposure*,bool)));
  connect(proc,SIGNAL(selected(Info::Task*,bool)),
	  launch,SLOT(select(Info::Task*,bool)));

  proc=ProcButton::instantiate(Xmm::OM,bar); //
  connect(exposuresView,SIGNAL(selected(OdfInfo::ObservationExposure*,bool)),
	  proc,SLOT(selected(OdfInfo::ObservationExposure*,bool)));
  connect(proc,SIGNAL(selected(Info::Task*,bool)),
	  launch,SLOT(select(Info::Task*,bool)));
  bar->addSeparator();
  
}

OdfBrowserGui::~OdfBrowserGui()
{
}
