// -*-C++-*-
//
// File:      RunButton.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Tue Jul 10 10:38:24 MET DST 2001

#include "RunButton.h"
#include "Xmm.h"
#include "Task.h"
#include <qtoolbar.h>
#include <qtooltip.h>
#include <qdialog.h>

#include "ParamDialog.h"
#include <ExceptionErrorHandler.h>
#include <errstr.h>
#include <qmessagebox.h>

#include <list>
#include <algorithm> // find!

#include "runproc.xpm"

using namespace OdfBrowser;

// localized!
class RunButton::TaskList : public list<Info::Task*> {};


RunButton::RunButton(QToolBar* parent, const char* name) : 
  QToolButton(QPixmap(runproc_xpm),"sequentially run the procs",QString::null,0,0,parent,name),_procs(0)
{

  // << taken from one of the QToolButton constructors
  if ( parent->mainWindow() ) {
    connect( parent->mainWindow(), SIGNAL(pixmapSizeChanged(bool)),
	     this, SLOT(setUsesBigPixmap(bool)) );
    setUsesBigPixmap( parent->mainWindow()->usesBigPixmaps() );
  } else {
    setUsesBigPixmap( false );
  }
  // >>
  
  
  connect(this,SIGNAL(clicked()),this,SLOT(run()));
  setEnabled(false);  

  _procs=new TaskList;
}

RunButton::~RunButton()
{
  delete _procs;
}

void RunButton::select(Info::Task* t,bool on)
{
  if (!t) return;
  TaskList::iterator it=std::find(_procs->begin(),_procs->end(),t);
  if (it != _procs->end()) {if (!on) _procs->erase(it);}
  else {if (on) _procs->push_back(t);}

  // enable/disable this button.
  setEnabled(!_procs->empty());
}

void RunButton::run()
{
  ExceptionErrorHandler local;
  ErrorHandler* oldHandler = errHandler.handler(&local);
  const bool invoke=true;
  for(TaskList::iterator it=_procs->begin();it!=_procs->end();it++) {
      Info::Task* proc=(*it);
      try {
	proc->exec(invoke);
      }
      catch (SasException::Error e) {
	QString message(e.message.c_str());
	message+="\nContinue processing other procs?";

	switch( QMessageBox::warning(this,proc->name(),message,"yes","no",QString::null,0,1)) {
	case 0: // Try again or Enter
	  // try again
	  break;
	case 1: // Quit or Escape
	  // exit
	  errHandler.handler(oldHandler);
	  return;
	}
      }
  }
  errHandler.handler(oldHandler); // return to default error handler
}
